@@ -1,7 +1,9 @@
-from typing import Optional
+from typing import Any, Optional
 
 import click
+from click import UsageError
 
+from ggshield.cmd.common_options import add_common_options
 from ggshield.core.config import Config
 
 from .constants import FIELD_OPTIONS
@@ -17,9 +19,14 @@ from .constants import FIELD_OPTIONS
     metavar="URL",
     help="Set per instance configuration.",
 )
+@add_common_options()
 @click.pass_context
 def config_set_command(
-    ctx: click.Context, field_name: str, value: str, instance: Optional[str]
+    ctx: click.Context,
+    field_name: str,
+    value: str,
+    instance: Optional[str],
+    **kwargs: Any,
 ) -> int:
     """
     Update the value of the given configuration key.
@@ -31,7 +38,7 @@ def config_set_command(
         try:
             value = int(value)  # type: ignore
         except ValueError:
-            raise click.ClickException("default_token_lifetime must be an int")
+            raise UsageError("default_token_lifetime must be an int")
 
     if instance is None:
         setattr(config.auth_config, field_name, value)
