@@ -3,22 +3,20 @@ from pathlib import Path
 from typing import Any, Optional, Sequence, Type
 
 import click
+from pygitguardian.iac_models import IaCScanParameters, IaCScanResult
 from pygitguardian.models import Detail
 
+from ggshield.cmd.common_options import add_common_options
 from ggshield.core.client import create_client_from_config
 from ggshield.core.config import Config
-from ggshield.core.extra_headers import get_headers
 from ggshield.core.filter import init_exclusion_regexes
 from ggshield.core.text_utils import display_error
-from ggshield.core.utils import ScanContext, ScanMode
 from ggshield.iac.filter import get_iac_files_from_paths
-from ggshield.iac.models import IaCScanResult
-from ggshield.iac.models.iac_scan_parameters import IaCScanParameters
-from ggshield.iac.utils import POLICY_ID_PATTERN, create_tar, validate_policy_id
+from ggshield.iac.policy_id import POLICY_ID_PATTERN, validate_policy_id
 from ggshield.output import OutputHandler
 from ggshield.output.json.iac_json_output_handler import IaCJSONOutputHandler
 from ggshield.output.text.iac_text_output_handler import IaCTextOutputHandler
-from ggshield.scan import ScanCollection
+from ggshield.scan import ScanCollection, ScanContext, ScanMode
 
 
 logger = logging.getLogger(__name__)
@@ -70,27 +68,34 @@ def validate_exclude(_ctx: Any, _param: Any, value: Sequence[str]) -> Sequence[s
     "directory",
     type=click.Path(exists=True, readable=True, path_type=Path, file_okay=False),
 )
+@add_common_options()
 @click.pass_context
 def scan_cmd(
     ctx: click.Context,
     exit_zero: bool,
     minimum_severity: str,
-    verbose: bool,
     ignore_policies: Sequence[str],
     ignore_paths: Sequence[str],
     json: bool,
     directory: Path,
+    **kwargs: Any,
 ) -> int:
     """
     Scan a directory for IaC vulnerabilities.
     """
-    update_context(
-        ctx, exit_zero, minimum_severity, verbose, ignore_policies, ignore_paths, json
-    )
+    update_context(ctx, exit_zero, minimum_severity, ignore_policies, ignore_paths)
     result = iac_scan(ctx, directory)
     scan = ScanCollection(id=str(directory), type="path_scan", iac_result=result)
 
-    output_handler: OutputHandler = ctx.obj["output_handler"]
+    output_handler_cls: Type[OutputHandler]
+    if json:
+        output_handler_cls = IaCJSONOutputHandler
+    else:
+        output_handler_cls = IaCTextOutputHandler
+    config: Config = ctx.obj["config"]
+    output_handler = output_handler_cls(
+        show_secrets=False, verbose=config.user_config.verbose
+    )
     return output_handler.process_scan(scan)
 
 
@@ -98,10 +103,8 @@ def update_context(
     ctx: click.Context,
     exit_zero: bool,
     minimum_severity: str,
-    verbose: bool,
     ignore_policies: Sequence[str],
     ignore_paths: Sequence[str],
-    json: bool,
 ) -> None:
     config: Config = ctx.obj["config"]
     ctx.obj["client"] = create_client_from_config(config)
@@ -116,23 +119,12 @@ def update_context(
     if ignore_policies is not None:
         config.user_config.iac.ignored_policies.update(ignore_policies)
 
-    if verbose is not None:
-        config.user_config.verbose = verbose
-
     if exit_zero is not None:
         config.user_config.exit_zero = exit_zero
 
     if minimum_severity is not None:
         config.user_config.iac.minimum_severity = minimum_severity
 
-    output_handler_cls: Type[OutputHandler] = IaCTextOutputHandler
-    if json:
-        output_handler_cls = IaCJSONOutputHandler
-
-    ctx.obj["output_handler"] = output_handler_cls(
-        show_secrets=False, verbose=config.user_config.verbose
-    )
-
 
 def iac_scan(ctx: click.Context, directory: Path) -> Optional[IaCScanResult]:
     files = get_iac_files_from_paths(
@@ -142,7 +134,6 @@ def iac_scan(ctx: click.Context, directory: Path) -> Optional[IaCScanResult]:
         # If the repository is a git repository, ignore untracked files
         ignore_git=False,
     )
-    tar = create_tar(directory, files)
 
     config = ctx.obj["config"]
     client = ctx.obj["client"]
@@ -151,16 +142,14 @@ def iac_scan(ctx: click.Context, directory: Path) -> Optional[IaCScanResult]:
         config.user_config.iac.ignored_policies, config.user_config.iac.minimum_severity
     )
 
-    scan = client.directory_scan(
-        tar,
+    scan = client.iac_directory_scan(
+        directory,
+        files.filenames,
         scan_parameters,
-        get_headers(
-            scan_context=ScanContext(
-                command_path=ctx.command_path,
-                scan_mode=ScanMode.IAC_DIRECTORY,
-            ),
-            context_headers=ctx.obj.get("headers"),
-        ),
+        ScanContext(
+            command_path=ctx.command_path,
+            scan_mode=ScanMode.IAC_DIRECTORY,
+        ).get_http_headers(),
     )
 
     if not scan.success or not isinstance(scan, IaCScanResult):
