@@ -1,21 +1,33 @@
 import os
-from typing import List
+from enum import Enum
+from typing import Any, List
 
 import click
+from click import UsageError
 
-from ggshield.core.cache import ReadOnlyCache
-from ggshield.core.extra_headers import add_extra_header
-from ggshield.core.git_shell import check_git_dir, get_list_commit_SHA
-from ggshield.core.utils import (
-    EMPTY_SHA,
-    ScanContext,
-    ScanMode,
-    SupportedCI,
-    handle_exception,
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
 )
+from ggshield.core.cache import ReadOnlyCache
+from ggshield.core.errors import UnexpectedError, handle_exception
+from ggshield.core.git_shell import check_git_dir, get_list_commit_SHA
+from ggshield.core.utils import EMPTY_SHA
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.repo import scan_commit_range
 
 
+class SupportedCI(Enum):
+    GITLAB = "GITLAB"
+    TRAVIS = "TRAVIS"
+    CIRCLECI = "CIRCLECI"
+    JENKINS = "JENKINS HOME"
+    GITHUB = "GITHUB ACTIONS"
+    BITBUCKET = "BITBUCKET PIPELINES"
+    DRONE = "DRONE"
+    AZURE = "AZURE PIPELINES"
+
+
 def jenkins_range(verbose: bool) -> List[str]:  # pragma: no cover
     head_commit = os.getenv("GIT_COMMIT")
     previous_commit = os.getenv("GIT_PREVIOUS_COMMIT")
@@ -35,7 +47,7 @@ def jenkins_range(verbose: bool) -> List[str]:  # pragma: no cover
     if commit_list:
         return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "\tRepository URL: <Fill if public>\n"
         f"\tGIT_COMMIT: {head_commit}"
@@ -62,7 +74,7 @@ def travis_range(verbose: bool) -> List[str]:  # pragma: no cover
     if commit_list:
         return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "\tRepository URL: <Fill if public>\n"
         f"\tTRAVIS_COMMIT_RANGE: {commit_range}"
@@ -79,7 +91,7 @@ def bitbucket_pipelines_range(verbose: bool) -> List[str]:  # pragma: no cover
     if commit_list:
         return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "  Repository URL: <Fill if public>\n"
         f"  CI_COMMIT_SHA: {commit_sha}"
@@ -113,7 +125,7 @@ def circle_ci_range(verbose: bool) -> List[str]:  # pragma: no cover
     if commit_list:
         return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "\tRepository URL: <Fill if public>\n"
         f"\tCIRCLE_RANGE: {compare_range}\n"
@@ -150,7 +162,7 @@ def gitlab_ci_range(verbose: bool) -> List[str]:  # pragma: no cover
     if commit_list:
         return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "  Repository URL: <Fill if public>\n"
         f"  CI_MERGE_REQUEST_TARGET_BRANCH_NAME: {merge_request_target_branch}\n"
@@ -201,7 +213,7 @@ def github_actions_range(verbose: bool) -> List[str]:  # pragma: no cover
         if commit_list:
             return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "  Repository URL: <Fill if public>\n"
         f"github_push_before_sha: {push_before_sha}\n"
@@ -223,7 +235,7 @@ def drone_range(verbose: bool) -> List[str]:  # pragma: no cover
         if commit_list:
             return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "  Repository URL: <Fill if public>\n"
         f"  DRONE_COMMIT_BEFORE: {before_sha}"
@@ -241,7 +253,7 @@ def azure_range(verbose: bool) -> List[str]:  # pragma: no cover
         if commit_list:
             return commit_list
 
-    raise click.ClickException(
+    raise UnexpectedError(
         "Unable to get commit range. Please submit an issue with the following info:\n"
         "  Repository URL: <Fill if public>\n"
         f"  BUILD_SOURCEVERSION: {head_commit}"
@@ -249,8 +261,9 @@ def azure_range(verbose: bool) -> List[str]:  # pragma: no cover
 
 
 @click.command()
+@add_secret_scan_common_options()
 @click.pass_context
-def ci_cmd(ctx: click.Context) -> int:
+def ci_cmd(ctx: click.Context, **kwargs: Any) -> int:
     """
     scan in a CI environment.
     """
@@ -260,7 +273,7 @@ def ci_cmd(ctx: click.Context) -> int:
         if not (
             os.getenv("CI") or os.getenv("JENKINS_HOME") or os.getenv("BUILD_BUILDID")
         ):
-            raise click.ClickException(
+            raise UsageError(
                 "`secret scan ci` should only be used in a CI environment."
             )
 
@@ -289,13 +302,11 @@ def ci_cmd(ctx: click.Context) -> int:
             commit_list = azure_range(config.verbose)
             ci_mode = SupportedCI.AZURE
         else:
-            raise click.ClickException(
+            raise UnexpectedError(
                 f"Current CI is not detected or supported."
                 f" Supported CIs: {', '.join([ci.value for ci in SupportedCI])}."
             )
 
-        add_extra_header(ctx, "Ci-Mode", ci_mode.name)
-
         mode_header = f"{ScanMode.CI.value}/{ci_mode.value}"
 
         if config.verbose:
@@ -304,13 +315,14 @@ def ci_cmd(ctx: click.Context) -> int:
         scan_context = ScanContext(
             scan_mode=mode_header,
             command_path=ctx.command_path,
+            extra_headers={"Ci-Mode": ci_mode.name},
         )
 
         return scan_commit_range(
             client=ctx.obj["client"],
             cache=ReadOnlyCache(),
             commit_list=commit_list,
-            output_handler=ctx.obj["output_handler"],
+            output_handler=create_output_handler(ctx),
             exclusion_regexes=ctx.obj["exclusion_regexes"],
             matches_ignore=config.secret.ignored_matches,
             scan_context=scan_context,
