@@ -1,10 +1,15 @@
 import tempfile
 from pathlib import Path
+from typing import Any
 
 import click
 
-from ggshield.core.utils import ScanContext, ScanMode, handle_exception
-from ggshield.output import OutputHandler
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
+from ggshield.core.errors import handle_exception
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.docker import docker_save_to_tmp, docker_scan_archive
 
 
@@ -22,8 +27,11 @@ DOCKER_COMMAND_TIMEOUT = 360
     show_default=True,
 )
 @click.argument("name", nargs=1, type=click.STRING, required=True)
+@add_secret_scan_common_options()
 @click.pass_context
-def docker_name_cmd(ctx: click.Context, name: str, docker_timeout: int) -> int:
+def docker_name_cmd(
+    ctx: click.Context, name: str, docker_timeout: int, **kwargs: Any
+) -> int:
     """
     scan a docker image <NAME>.
 
@@ -32,7 +40,7 @@ def docker_name_cmd(ctx: click.Context, name: str, docker_timeout: int) -> int:
 
     with tempfile.TemporaryDirectory(suffix="ggshield") as temporary_dir:
         config = ctx.obj["config"]
-        output_handler: OutputHandler = ctx.obj["output_handler"]
+        output_handler = create_output_handler(ctx)
 
         try:
             archive = Path(temporary_dir) / "archive.tar"
@@ -50,6 +58,7 @@ def docker_name_cmd(ctx: click.Context, name: str, docker_timeout: int) -> int:
                 scan_context=scan_context,
                 matches_ignore=config.secret.ignored_matches,
                 ignored_detectors=config.secret.ignored_detectors,
+                ignore_known_secrets=config.ignore_known_secrets,
             )
 
             return output_handler.process_scan(scan)
