@@ -3,12 +3,11 @@ from dataclasses import fields, is_dataclass
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union
 
-import click
 import yaml
-from appdirs import user_config_dir
 
 from ggshield.core.constants import AUTH_CONFIG_FILENAME
-from ggshield.core.text_utils import display_error
+from ggshield.core.dirs import get_config_dir
+from ggshield.core.errors import UnexpectedError
 
 
 def replace_in_keys(data: Union[List, Dict], old_char: str, new_char: str) -> None:
@@ -24,23 +23,25 @@ def replace_in_keys(data: Union[List, Dict], old_char: str, new_char: str) -> No
             replace_in_keys(element, old_char=old_char, new_char=new_char)
 
 
-def load_yaml(path: str) -> Optional[Dict[str, Any]]:
+def load_yaml_dict(path: str) -> Optional[Dict[str, Any]]:
     if not os.path.isfile(path):
         return None
 
     with open(path, "r") as f:
         try:
             data = yaml.safe_load(f) or {}
-        except Exception as e:
-            message = f"Parsing error while reading {path}:\n{str(e)}"
-            display_error(message)
-            return None
-        else:
-            replace_in_keys(data, old_char="-", new_char="_")
-            return data
+        except (yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
+            message = f"{path} is not a valid YAML file:\n{str(e)}"
+            raise ValueError(message)
+
+    if not isinstance(data, dict):
+        raise ValueError(f"{path} should be a dictionary.")
+
+    replace_in_keys(data, old_char="-", new_char="_")
+    return data
 
 
-def save_yaml(data: Dict[str, Any], path: str) -> None:
+def save_yaml_dict(data: Dict[str, Any], path: str) -> None:
     replace_in_keys(data, "_", "-")
     p = Path(path)
     p.parent.mkdir(parents=True, exist_ok=True)
@@ -49,17 +50,13 @@ def save_yaml(data: Dict[str, Any], path: str) -> None:
             stream = yaml.dump(data, indent=2, default_flow_style=False)
             f.write(stream)
         except Exception as e:
-            raise click.ClickException(
+            raise UnexpectedError(
                 f"Error while saving config in {path}:\n{str(e)}"
             ) from e
 
 
-def get_auth_config_dir() -> str:
-    return user_config_dir(appname="ggshield", appauthor="GitGuardian")
-
-
 def get_auth_config_filepath() -> str:
-    return os.path.join(get_auth_config_dir(), AUTH_CONFIG_FILENAME)
+    return os.path.join(get_config_dir(), AUTH_CONFIG_FILENAME)
 
 
 def get_global_path(filename: str) -> str:
