@@ -1,13 +1,18 @@
 import os
 
 
-# max file size to accept
-MAX_FILE_SIZE = 1048576
 # max files size to create a tar from
 MAX_TAR_CONTENT_SIZE = 30 * 1024 * 1024
 
 CPU_COUNT = os.cpu_count() or 1
 
+
+def _get_max_workers() -> int:
+    # We add a max value to avoid silently consuming all threads on powerful machines
+    return int(os.getenv("GG_MAX_WORKERS", "32"))
+
+
+MAX_WORKERS = min(CPU_COUNT, _get_max_workers())
 CACHE_FILENAME = "./.cache_ggshield"
 GLOBAL_CONFIG_FILENAMES = [".gitguardian", ".gitguardian.yml", ".gitguardian.yaml"]
 LOCAL_CONFIG_PATHS = ["./.gitguardian", "./.gitguardian.yml", "./.gitguardian.yaml"]
