@@ -1,14 +1,13 @@
 import logging
 import os
 import re
-import traceback
-import uuid
-from dataclasses import dataclass
+from datetime import datetime
 from enum import Enum
-from typing import Iterable, List, NamedTuple, Optional, Union
+from typing import Iterable, List, NamedTuple, Optional
 from urllib.parse import ParseResult, urlparse
 
 import click
+from click import UsageError
 from dotenv import load_dotenv
 from pygitguardian.models import Match
 
@@ -210,31 +209,6 @@ def find_match_indices(match: Match, lines: List[Line], is_patch: bool) -> Match
     )
 
 
-class SupportedCI(Enum):
-    GITLAB = "GITLAB"
-    TRAVIS = "TRAVIS"
-    CIRCLECI = "CIRCLECI"
-    JENKINS = "JENKINS HOME"
-    GITHUB = "GITHUB ACTIONS"
-    BITBUCKET = "BITBUCKET PIPELINES"
-    DRONE = "DRONE"
-    AZURE = "AZURE PIPELINES"
-
-
-class ScanMode(Enum):
-    REPO = "repo"
-    PATH = "path"
-    COMMIT_RANGE = "commit_range"
-    PRE_COMMIT = "pre_commit"
-    PRE_PUSH = "pre_push"
-    PRE_RECEIVE = "pre_receive"
-    CI = "ci"
-    DOCKER = "docker"
-    PYPI = "pypi"
-    ARCHIVE = "archive"
-    IAC_DIRECTORY = "directory"
-
-
 json_output_option_decorator = click.option(
     "--json",
     "json_output",
@@ -245,20 +219,6 @@ json_output_option_decorator = click.option(
 )
 
 
-def handle_exception(e: Exception, verbose: bool) -> int:
-    """
-    Handle exception from a scan command.
-    """
-    if isinstance(e, click.exceptions.Abort):
-        return 0
-    elif isinstance(e, click.ClickException):
-        raise e
-    else:
-        if verbose:
-            traceback.print_exc()
-        raise click.ClickException(str(e))
-
-
 def _find_dot_env() -> Optional[str]:
     """Look for a .env to load, returns its path if found"""
     env = os.getenv("GITGUARDIAN_DOTENV_PATH")
@@ -318,13 +278,13 @@ def dashboard_to_api_url(dashboard_url: str, warn: bool = False) -> str:
     handles the SaaS edge case where the host changes instead of the path
     """
     parsed_url = clean_url(dashboard_url, warn=warn)
-    if parsed_url.scheme != "https":
-        raise click.ClickException(
+    if parsed_url.scheme != "https" and not parsed_url.netloc.startswith("localhost"):
+        raise UsageError(
             f"Invalid scheme for dashboard URL '{dashboard_url}', expected HTTPS"
         )
     if any(parsed_url.netloc.endswith("." + domain) for domain in GITGUARDIAN_DOMAINS):
         if parsed_url.path:
-            raise click.ClickException(
+            raise UsageError(
                 f"Invalid dashboard URL '{dashboard_url}', got an unexpected path '{parsed_url.path}'"
             )
         parsed_url = parsed_url._replace(
@@ -343,13 +303,11 @@ def api_to_dashboard_url(api_url: str, warn: bool = False) -> str:
     handles the SaaS edge case where the host changes instead of the path
     """
     parsed_url = clean_url(api_url, warn=warn)
-    if parsed_url.scheme != "https":
-        raise click.ClickException(
-            f"Invalid scheme for API URL '{api_url}', expected HTTPS"
-        )
+    if parsed_url.scheme != "https" and not parsed_url.netloc.startswith("localhost"):
+        raise UsageError(f"Invalid scheme for API URL '{api_url}', expected HTTPS")
     if parsed_url.netloc.endswith(".gitguardian.com"):  # SaaS
         if parsed_url.path:
-            raise click.ClickException(
+            raise UsageError(
                 f"Invalid API URL '{api_url}', got an unexpected path '{parsed_url.path}'"
             )
         parsed_url = parsed_url._replace(
@@ -382,10 +340,8 @@ def urljoin(url: str, *args: str) -> str:
     return url
 
 
-@dataclass
-class ScanContext:
-    scan_mode: Union[ScanMode, str]
-    command_path: str
-
-    def __post_init__(self) -> None:
-        self.command_id = str(uuid.uuid4())
+def datetime_from_isoformat(text: str) -> datetime:
+    """Work around for datetime.isoformat() not supporting ISO dates ending with Z"""
+    if text.endswith("Z"):
+        text = text[:-1] + "+00:00"
+    return datetime.fromisoformat(text)
