@@ -6,19 +6,19 @@ from contextlib import contextmanager
 from functools import partial
 from typing import Callable, Iterable, Iterator, List, Optional, Set
 
-import click
+from click import UsageError
 from pygitguardian import GGClient
 from pygitguardian.config import MULTI_DOCUMENT_LIMIT
 
 from ggshield.core.cache import Cache
 from ggshield.core.config import Config
 from ggshield.core.constants import MAX_WORKERS
+from ggshield.core.errors import ExitCode, handle_exception
 from ggshield.core.git_shell import get_list_commit_SHA, is_git_dir
 from ggshield.core.text_utils import create_progress_bar, display_error
 from ggshield.core.types import IgnoredMatch
-from ggshield.core.utils import ScanContext, handle_exception
 from ggshield.output import OutputHandler
-from ggshield.scan import Commit, Files, Results, ScanCollection
+from ggshield.scan import Commit, Results, ScanCollection, ScanContext, SecretScanner
 
 
 # We add a maximal value to avoid silently consuming all threads on powerful machines
@@ -45,7 +45,7 @@ def scan_repo_path(
 ) -> int:  # pragma: no cover
     try:
         if not is_git_dir(repo_path):
-            raise click.ClickException(f"{repo_path} is not a git repository")
+            raise UsageError(f"{repo_path} is not a git repository")
 
         with cd(repo_path):
             return scan_commit_range(
@@ -57,6 +57,7 @@ def scan_repo_path(
                 matches_ignore=config.secret.ignored_matches,
                 scan_context=scan_context,
                 ignored_detectors=config.secret.ignored_detectors,
+                ignore_known_secrets=config.ignore_known_secrets,
             )
     except Exception as error:
         return handle_exception(error, config.verbose)
@@ -70,37 +71,39 @@ def scan_commits_content(
     scan_context: ScanContext,
     progress_callback: Callable[..., None],
     ignored_detectors: Optional[Set[str]] = None,
+    ignore_known_secrets: bool = False,
 ) -> ScanCollection:  # pragma: no cover
     try:
         commit_files = list(itertools.chain.from_iterable(c.files for c in commits))
+
         progress_callback(advance=len(commits))
-        results = Files(commit_files).scan(
+        scanner = SecretScanner(
             client=client,
             cache=cache,
-            matches_ignore=matches_ignore,
             scan_context=scan_context,
+            ignored_matches=matches_ignore,
             ignored_detectors=ignored_detectors,
+            ignore_known_secrets=ignore_known_secrets,
+        )
+        results = scanner.scan(
+            commit_files,
             scan_threads=SCAN_THREADS,
         )
     except Exception as exc:
         results = Results.from_exception(exc)
 
+    result_for_files = {result.file: result for result in results.results}
     scans = []
     for commit in commits:
-        concerned_results = [
-            res
-            for res in results.results
-            if any(
-                res.content == file.document and res.filename == file.filename
-                for file in commit.files
-            )
+        results_for_commit_files = [
+            result_for_files[file] for file in commit.files if file in result_for_files
         ]
         scans.append(
             ScanCollection(
                 commit.sha or "unknown",
                 type="commit",
                 results=Results(
-                    results=concerned_results,
+                    results=results_for_commit_files,
                     errors=results.errors,
                 ),
                 optional_header=commit.optional_header,
@@ -145,7 +148,8 @@ def scan_commit_range(
     matches_ignore: Iterable[IgnoredMatch],
     scan_context: ScanContext,
     ignored_detectors: Optional[Set[str]] = None,
-) -> int:  # pragma: no cover
+    ignore_known_secrets: bool = False,
+) -> ExitCode:
     """
     Scan every commit in a range.
 
@@ -181,6 +185,7 @@ def scan_commit_range(
                         scan_context,
                         partial(progress.update, task_scan),
                         ignored_detectors,
+                        ignore_known_secrets,
                     )
                 )
 
